==> tkvoice-1.2a.tar.gz: tkvoice-1.2a/TCL/tkvsetupprint.tcl <==
# tkvsetupprint.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvsetupprint
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Setup PRINTING"
wm iconname $w "tkVoice Setup PRINTING"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global printcmd printsel faxdpi

# START TOP IMAGE ##############################################
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoiceprint}
image create photo tkvoiceprint -file [file join $tkvoicedir/image/tkvoiceprint.gif]
label $w.gif.tkvoiceprint -image tkvoiceprint -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoiceprint -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right
# END TOP IMAGE ##############################################

label $w.msg -font $font -wraplength 5i -justify left -text "Choose Default FAX Printer:"
pack $w.msg -side top

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.print -text SAVE -command "savefax; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.print $w.buttons.cancel -side left -expand 1

frame $w.top
pack $w.top -side top -expand yes -pady .1c -padx .5c
set printers [exec lpc status | grep : | awk -F : {{print $1}}]
foreach x $printers  {
    radiobutton $w.top.p$x -text "$x" -variable printsel \
                -relief flat -value $x -command "set custprinter 0"
    pack $w.top.p$x -side top -pady 2 -anchor w
}
radiobutton $w.top.other -text "Other" -variable custprinter -relief flat -value 1
entry $w.top.entry -relief sunken -width 10 -textvariable printsel -background snow2
pack $w.top.other -side left  -pady 2
pack $w.top.entry -side right -pady 2

frame $w.mid
pack $w.mid -side top -expand yes -pady .1c -padx .5c
label $w.mid.msg -font $font -wraplength 5i -justify left -text "Print Command:"
pack $w.mid.msg -side top
entry $w.mid.cmdentry -relief sunken -width 10 -textvariable printcmd -background snow2
pack $w.mid.cmdentry -side right -pady 2

frame $w.low -borderwidth 10
pack $w.low -side top -fill x
label $w.low.msg -justify left -text "Use this slider to adjust print margins."
scale $w.low.scale -orient horizontal -length 300 -from 0 -to 100 \
        -command "setfaxdpi" -tickinterval 20
pack $w.low.scale $w.low.msg -side bottom -expand yes -anchor n
$w.low.scale set [expr $faxdpi-204]
 
proc setfaxdpi {dpi} {
global faxdpi
set faxdpi [expr $dpi+204]
}

==> tkvoice-1.3.tar.gz: tkvoice-1.3/TCL/tkvsetupprint.tcl <==
# tkvsetupprint.tcl --
#
#

if {![info exists tkVoice]} {
    error "This script should be run from within  \"tkvoice\"."
}

set w .tkvsetupprint
catch {destroy $w}
toplevel $w
wm title $w "tkVoice Setup PRINTING"
wm iconname $w "tkVoice Setup PRINTING"
wm iconbitmap $w @$tkvoicedir/image/icon
positionWindow $w

global printcmd printsel faxdpi
set bgcolor "#eeeeee"

# START TOP IMAGE ##############################################
frame $w.gif
pack $w.gif -side top -fill x

catch {image delete tkvoiceprint}
image create photo tkvoiceprint -file [file join $tkvoicedir/image/tkvoiceprint.gif]
label $w.gif.tkvoiceprint -image tkvoiceprint -bd 1 -relief sunken
label $w.gif.linux -image linux -bd 1 -relief sunken
label $w.gif.phone -image phone -bd 1 -relief sunken
label $w.gif.penguin -image penguin -bd 1 -relief sunken
 
pack $w.gif.phone -side left
pack $w.gif.tkvoiceprint -side left -expand 1 -fill x
pack $w.gif.linux -side right
pack $w.gif.penguin -side right
# END TOP IMAGE ##############################################

label $w.msg -font $font -wraplength 5i -justify left -text "Choose Default FAX Printer:"
pack $w.msg -side top

frame $w.buttons
pack $w.buttons -side bottom -fill x -pady 2m
button $w.buttons.print -text SAVE -command "savefax; destroy $w"
button $w.buttons.cancel -text CANCEL -command "destroy $w"
pack $w.buttons.print $w.buttons.cancel -side left -expand 1

frame $w.top
pack $w.top -side top -expand yes -pady .1c -padx .5c
set printers [exec lpc status | grep : | awk -F : {{print $1}}]
foreach x $printers  {
    radiobutton $w.top.p$x -text "$x" -variable printsel \
                -relief flat -value $x -command "set custprinter 0"
    pack $w.top.p$x -side top -pady 2 -anchor w
}
radiobutton $w.top.other -text "Other" -variable custprinter -relief flat -value 1
entry $w.top.entry -relief sunken -width 10 -textvariable printsel -background $bgcolor
pack $w.top.other -side left  -pady 2
pack $w.top.entry -side right -pady 2

frame $w.mid
pack $w.mid -side top -expand yes -pady .1c -padx .5c
label $w.mid.msg -font $font -wraplength 5i -justify left -text "Print Command:"
pack $w.mid.msg -side top
entry $w.mid.cmdentry -relief sunken -width 10 -textvariable printcmd -background $bgcolor
pack $w.mid.cmdentry -side right -pady 2

frame $w.low -borderwidth 10
pack $w.low -side top -fill x
label $w.low.msg -justify left -text "Use this slider to adjust print margins."
scale $w.low.scale -orient horizontal -length 300 -from 0 -to 100 \
        -command "setfaxdpi" -tickinterval 20
pack $w.low.scale $w.low.msg -side bottom -expand yes -anchor n
$w.low.scale set [expr $faxdpi-204]
 
proc setfaxdpi {dpi} {
global faxdpi
set faxdpi [expr $dpi+204]
}
